@@ -4,22 +4,24 @@ from mex.common.logging import logger
 from mex.common.models import (
     ExtractedOrganization,
     ExtractedOrganizationalUnit,
-    ExtractedPrimarySource,
 )
 from mex.common.organigram.models import OrganigramUnit
-from mex.common.types import Email, MergedOrganizationalUnitIdentifier
+from mex.common.types import (
+    MergedOrganizationalUnitIdentifier,
+    MergedPrimarySourceIdentifier,
+)
 
 
 def transform_organigram_unit_to_extracted_organizational_unit(
     organigram_unit: OrganigramUnit,
-    primary_source: ExtractedPrimarySource,
+    primary_source_id: MergedPrimarySourceIdentifier,
     rki_organization: ExtractedOrganization,
 ) -> ExtractedOrganizationalUnit:
     """Transform an organigram unit into an ExtractedOrganizationalUnit.
 
     Args:
         organigram_unit: Iterable of organigram units coming from the JSON file
-        primary_source: Primary source for organigram
+        primary_source_id: Primary source identifier for organigram
         rki_organization: RKI organization to which the unit belongs
 
     Returns:
@@ -27,10 +29,10 @@ def transform_organigram_unit_to_extracted_organizational_unit(
     """
     return ExtractedOrganizationalUnit(
         identifierInPrimarySource=organigram_unit.identifier,
-        hadPrimarySource=primary_source.stableTargetId,
+        hadPrimarySource=primary_source_id,
         alternativeName=organigram_unit.alternativeName,
         unitOf=[rki_organization.stableTargetId],
-        email=[Email(email) for email in organigram_unit.email],
+        email=organigram_unit.email,
         name=organigram_unit.name,
         shortName=organigram_unit.shortName,
         website=[organigram_unit.website] if organigram_unit.website else [],
@@ -39,7 +41,7 @@ def transform_organigram_unit_to_extracted_organizational_unit(
 
 def transform_organigram_units_to_organizational_units(
     organigram_units: Iterable[OrganigramUnit],
-    primary_source: ExtractedPrimarySource,
+    primary_source_id: MergedPrimarySourceIdentifier,
     rki_organization: ExtractedOrganization,
 ) -> list[ExtractedOrganizationalUnit]:
     """Transform organigram units into ExtractedOrganizationalUnits.
@@ -48,7 +50,7 @@ def transform_organigram_units_to_organizational_units(
 
     Args:
         organigram_units: Iterable of organigram units coming from the JSON file
-        primary_source: Primary source for organigram
+        primary_source_id: Primary source for organigram
         rki_organization: RKI organization to which the units belong
 
     Returns:
@@ -59,7 +61,7 @@ def transform_organigram_units_to_organizational_units(
 
     for unit in organigram_units:
         extracted_unit = transform_organigram_unit_to_extracted_organizational_unit(
-            unit, primary_source, rki_organization
+            unit, primary_source_id, rki_organization
         )
         extracted_unit_by_id_in_primary_source[unit.identifier] = extracted_unit
         if parent_identifier_in_primary_source := unit.parentUnit:
