@@ -43,22 +43,3 @@ def transform_seed_primary_sources_to_extracted_primary_sources(
     ]
     logger.info("transformed %s primary sources", len(extracted_primary_sources))
     return extracted_primary_sources
-
-
-# TODO(EH): Remove this in MX-1698
-def get_primary_sources_by_name(
-    extracted_primary_sources: Iterable[ExtractedPrimarySource], *names: str
-) -> tuple[ExtractedPrimarySource, ...]:
-    """Pick the extracted primary sources with the given name and return as a tuple.
-
-    Args:
-        extracted_primary_sources: Iterable of extracted primary sources
-        names: Names (`identifierInPrimarySource`) to pick
-
-    Returns:
-        Tuple of picked primary sources of the same length as `names`
-    """
-    primary_sources_by_name = {
-        p.identifierInPrimarySource: p for p in extracted_primary_sources
-    }
-    return tuple(primary_sources_by_name[n] for n in names)
